# -*- coding: utf-8 -*- #
# Copyright 2014 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating images."""


from googlecloudsdk.calliope import base


@base.UniverseCompatible
@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class Images(base.Group):
  """List, create, and delete Compute Engine images."""


Images.category = base.INSTANCES_CATEGORY

Images.detailed_help = {
    'DESCRIPTION': """
        Create and manipulate Compute Engine images.

        For more information about images, see the
        [images documentation](https://cloud.google.com/compute/docs/images).

        See also: [Images API](https://cloud.google.com/compute/docs/reference/rest/v1/images).
    """,
}
